@@ -1,12 +1,12 @@
 package SPOPS::Export::Perl;
 
-# $Id: Perl.pm,v 3.1 2002/09/03 11:43:22 lachoy Exp $
+# $Id: Perl.pm,v 3.2 2003/01/02 06:00:23 lachoy Exp $
 
 use strict;
 use base qw( SPOPS::Export );
 use Data::Dumper qw( Dumper );
 
-$SPOPS::Export::Perl::VERSION  = sprintf("%d.%02d", q$Revision: 3.1 $ =~ /(\d+)\.(\d+)/);
+$SPOPS::Export::Perl::VERSION  = sprintf("%d.%02d", q$Revision: 3.2 $ =~ /(\d+)\.(\d+)/);
 
 my @track = ();
 
@@ -69,4 +69,4 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters <chris@cwinters.com>
+Chris Winters E<lt>chris@cwinters.comE<gt>
