@@ -1,19 +1,19 @@
 package My::User;
 
-# $Id: User.pm,v 3.1 2003/01/02 05:59:06 lachoy Exp $
+# $Id: User.pm,v 3.2 2003/07/15 12:19:47 lachoy Exp $
 
 use strict;
 use SPOPS::Initialize;
 use SPOPS::Secure qw( :level :scope );
 
-$My::User::VERSION = sprintf("%d.%02d", q$Revision: 3.1 $ =~ /(\d+)\.(\d+)/);
+$My::User::VERSION = sprintf("%d.%02d", q$Revision: 3.2 $ =~ /(\d+)\.(\d+)/);
 $My::User::crypt_password = undef;
 
 sub _base_config {
    my $config = {
          user => {
              class        => 'My::User',
-             isa          => [ 'SPOPS::Secure', 'My::Common' ],
+             isa          => [ 'My::CommonResources', 'SPOPS::Secure', 'My::Common' ],
              rules_from   => [ 'SPOPS::Tool::DBI::DiscoverField' ],
              field_discover => 'yes',
              field        => [],
